@@ -33,7 +33,7 @@
 #' @importFrom vctrs vec_restore
 #' @importFrom vctrs vec_size
 #' @importFrom vctrs vec_slice
-#' @importFrom cli symbol
+#' @importFrom cli symbol ansi_strwrap
 NULL
 
 # nolint start
@@ -60,11 +60,6 @@ NULL
     debug_info()
   }
 
-  # https://github.com/r-lib/pkgdown/issues/1540
-  if (Sys.getenv("IN_PKGDOWN") != "") {
-    s3_register("pillar::type_sum", "accel")
-  }
-
   invisible()
 }
 
